@@ -26,12 +26,18 @@ sub time       { EV::time       }
 sub now        { EV::now        }
 sub now_update { EV::now_update }
 
+*AE::timer = \&EV::timer;
+
 sub timer {
    my ($class, %arg) = @_;
 
    EV::timer $arg{after}, $arg{interval}, $arg{cb}
 }
 
+*AE::io = defined &EV::_ae_io
+   ? \&EV::_ae_io
+   : sub($$$) { EV::io $_[0], $_[1] ? EV::WRITE : EV::READ, $_[2] };
+
 sub io {
    my ($class, %arg) = @_;
 
@@ -47,6 +53,8 @@ sub signal {
    EV::signal $arg{signal}, $arg{cb}
 }
 
+*AE::signal = \&EV::signal;
+
 sub child {
    my ($class, %arg) = @_;
 
@@ -57,12 +65,18 @@ sub child {
    }
 }
 
+*AE::child = sub($$) {
+   EV::child $_[0], 0, $_[1]
+};
+
 sub idle {
    my ($class, %arg) = @_;
 
    EV::idle $arg{cb}
 }
 
+*AE::idle = \&EV::idle;
+
 sub one_event {
    EV::loop EV::LOOP_ONESHOT;
 }
